package zendesk.messaging.android

/**
 * Convenience API to be notified when an asynchronous task is successful.
 *
 * @param T the type returned by the task
 */
public fun interface SuccessCallback<T> {

    /**
     * Called with a [value] of [T] when the task was successful.
     *
     * @param value the returned value [T]
     */
    public fun onSuccess(value: T)
}

/**
 * Convenience API to be notified when an asynchronous task failed.
 *
 * @param E the [Throwable] type returned
 */
public fun interface FailureCallback<E : Throwable> {

    /**
     * Called with an optional [Throwable] of type [E] when the task failed.
     *
     * @param cause the optional [Throwable] that caused the failure
     */
    public fun onFailure(cause: E?)
}
